<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Kustuta</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">Täisekraan</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">Slaidiseanss</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Ekspordi</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">Kopeeri</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">Lemmik</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">Määra taustapildiks</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">Näita failihalduris</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">Foto info</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">Taasta</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Nimetu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Loo</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Uus album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Oled sa kindel, et soovid seda albumit kustutada?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Prügikasti</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Lemmikud</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impordi</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Prügikasti</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Lemmikud</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Või lohista fotod siia</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Impordi kõik</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impordi</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Süsteemiketas</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerii</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoreeri</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Asenda</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspordi</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumendid</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Allalaadimsied</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Töölaud</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videod</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muusika</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salvesta kohta:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Vorming:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvaliteet:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Vali teine kaust</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Faili nimi ei saa olla tühi</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 ketas</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 krüpteeritud</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Ekspordi fotod</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Kustutamine...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Taastamine...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Põhiinfo</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Üksikasjad</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Impordi</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeta ümber</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspordi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Seade</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerii</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumid</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus album</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotod</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Abiinfo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Nimeta album ümber</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album “%1” on eemaldatud</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importimine oli edukas</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Importimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Eksporditud</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Kõik fotod</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Ajateljed</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumid</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Välju täisekraanist/slaidiseansist</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näita otseteesid</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vaata</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Vali kõik</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importimine</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Kustuta</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Välk</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Liik</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Failisuurus</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Mõõdud</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Pildistamise kuupäev</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Muutmise kuupäev</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fookuskaugus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mõõtmise režiim</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Valge tasakaal</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vägu kompensatsioon</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kaamera mudel</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Läätse mudel</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Värviruum</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Süsteemiketas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Vali</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Tühista valik</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Tühista</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Taasta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotod</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videod</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importimine...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Otsing ei andnud tulemusi</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Otsingu tulemused</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Vaata</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspordi</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Foto info</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Lisa albumisse</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eemalda albumist</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Taasta</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Prindi</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">päeva</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Põhiinfo</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Muutmise kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Liik</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Failisuurus</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Pildistamise kuupäev</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
